# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAuditResponse(Model):
    """BillAuditResponse.

    :param auditor_id:
    :type auditor_id: int
    :param auditor_code:
    :type auditor_code: str
    :param auditor_info:
    :type auditor_info: str
    :param description:
    :type description: str
    :param audit_category:
    :type audit_category: ~energycap.sdk.models.AuditCategory
    :param recommended:
    :type recommended: bool
    :param alert_severity:
    :type alert_severity: ~energycap.sdk.models.AlertSeverityResponse
    :param skip_zero_comparison_option:
    :type skip_zero_comparison_option: bool
    :param properties:
    :type properties: list[~energycap.sdk.models.AuditProperty]
    """

    _attribute_map = {
        'auditor_id': {'key': 'auditorId', 'type': 'int'},
        'auditor_code': {'key': 'auditorCode', 'type': 'str'},
        'auditor_info': {'key': 'auditorInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'audit_category': {'key': 'auditCategory', 'type': 'AuditCategory'},
        'recommended': {'key': 'recommended', 'type': 'bool'},
        'alert_severity': {'key': 'alertSeverity', 'type': 'AlertSeverityResponse'},
        'skip_zero_comparison_option': {'key': 'skipZeroComparisonOption', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '[AuditProperty]'},
    }

    def __init__(self, auditor_id=None, auditor_code=None, auditor_info=None, description=None, audit_category=None, recommended=None, alert_severity=None, skip_zero_comparison_option=None, properties=None):
        super(BillAuditResponse, self).__init__()
        self.auditor_id = auditor_id
        self.auditor_code = auditor_code
        self.auditor_info = auditor_info
        self.description = description
        self.audit_category = audit_category
        self.recommended = recommended
        self.alert_severity = alert_severity
        self.skip_zero_comparison_option = skip_zero_comparison_option
        self.properties = properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerformanceComparison(Model):
    """PerformanceComparison.

    :param id:
    :type id: int
    :param label:
    :type label: str
    :param cy_cost:
    :type cy_cost: float
    :param py_cost:
    :type py_cost: float
    :param cost_display:
    :type cost_display: str
    :param cost_percent_diff:
    :type cost_percent_diff: float
    :param use_percent_diff:
    :type use_percent_diff: float
    :param third_value_display:
    :type third_value_display: str
    :param third_value_percent_diff:
    :type third_value_percent_diff: float
    :param cy_display:
    :type cy_display: str
    :param py_display:
    :type py_display: str
    :param cy_global_use:
    :type cy_global_use: float
    :param py_global_use:
    :type py_global_use: float
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'label': {'key': 'label', 'type': 'str'},
        'cy_cost': {'key': 'cyCost', 'type': 'float'},
        'py_cost': {'key': 'pyCost', 'type': 'float'},
        'cost_display': {'key': 'costDisplay', 'type': 'str'},
        'cost_percent_diff': {'key': 'costPercentDiff', 'type': 'float'},
        'use_percent_diff': {'key': 'usePercentDiff', 'type': 'float'},
        'third_value_display': {'key': 'thirdValueDisplay', 'type': 'str'},
        'third_value_percent_diff': {'key': 'thirdValuePercentDiff', 'type': 'float'},
        'cy_display': {'key': 'cyDisplay', 'type': 'str'},
        'py_display': {'key': 'pyDisplay', 'type': 'str'},
        'cy_global_use': {'key': 'cyGlobalUse', 'type': 'float'},
        'py_global_use': {'key': 'pyGlobalUse', 'type': 'float'},
    }

    def __init__(self, id=None, label=None, cy_cost=None, py_cost=None, cost_display=None, cost_percent_diff=None, use_percent_diff=None, third_value_display=None, third_value_percent_diff=None, cy_display=None, py_display=None, cy_global_use=None, py_global_use=None):
        super(PerformanceComparison, self).__init__()
        self.id = id
        self.label = label
        self.cy_cost = cy_cost
        self.py_cost = py_cost
        self.cost_display = cost_display
        self.cost_percent_diff = cost_percent_diff
        self.use_percent_diff = use_percent_diff
        self.third_value_display = third_value_display
        self.third_value_percent_diff = third_value_percent_diff
        self.cy_display = cy_display
        self.py_display = py_display
        self.cy_global_use = cy_global_use
        self.py_global_use = py_global_use



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProcessAudits(Model):
    """ProcessAudits.

    :param audit_group_ids:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Cannot be Empty</span>
    :type audit_group_ids: list[int]
    :param filters:  <span class='property-internal'>Required</span>
    :type filters: list[~energycap.sdk.models.FilterEdit]
    :param use_stored_filters:  <span
     class='property-internal'>Required</span>
    :type use_stored_filters: bool
    """

    _validation = {
        'audit_group_ids': {'required': True},
        'filters': {'required': True},
        'use_stored_filters': {'required': True},
    }

    _attribute_map = {
        'audit_group_ids': {'key': 'auditGroupIds', 'type': '[int]'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
        'use_stored_filters': {'key': 'useStoredFilters', 'type': 'bool'},
    }

    def __init__(self, audit_group_ids, filters, use_stored_filters):
        super(ProcessAudits, self).__init__()
        self.audit_group_ids = audit_group_ids
        self.filters = filters
        self.use_stored_filters = use_stored_filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DynamicPercentageBillSplit(Model):
    """Defines details for a dynamic percentage split of use, cost, or both based
    on the use or cost values of the meters in the destination meter group.

    :param destination_meter_group_id: ID of a meter group to receive the
     results of the split bill. <span class='property-internal'>Required</span>
    :type destination_meter_group_id: int
    :param source_value_to_split: Value to distribute to the destination
     meters. <span class='property-internal'>Required</span> <span
     class='property-internal'>One of use, cost, useAndCost </span>
    :type source_value_to_split: str
    :param destination_share_value: Value to define how dynamic percentages
     are calculated. <span class='property-internal'>Required</span> <span
     class='property-internal'>One of use, cost </span>
    :type destination_share_value: str
    """

    _validation = {
        'destination_meter_group_id': {'required': True},
        'source_value_to_split': {'required': True},
        'destination_share_value': {'required': True},
    }

    _attribute_map = {
        'destination_meter_group_id': {'key': 'destinationMeterGroupId', 'type': 'int'},
        'source_value_to_split': {'key': 'sourceValueToSplit', 'type': 'str'},
        'destination_share_value': {'key': 'destinationShareValue', 'type': 'str'},
    }

    def __init__(self, destination_meter_group_id, source_value_to_split, destination_share_value):
        super(DynamicPercentageBillSplit, self).__init__()
        self.destination_meter_group_id = destination_meter_group_id
        self.source_value_to_split = source_value_to_split
        self.destination_share_value = destination_share_value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DestinationAccountResponse(Model):
    """DestinationAccountResponse.

    :param account_id: The account identifier
    :type account_id: int
    :param account_code: The account code
    :type account_code: str
    :param account_info: The account info
    :type account_info: str
    :param vendor: The account's vendor
    :type vendor: ~energycap.sdk.models.VendorChild
    :param meters: An array of identifiers for meters attached to this account
    :type meters: list[~energycap.sdk.models.DestinationAccountMeterChild]
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'meters': {'key': 'meters', 'type': '[DestinationAccountMeterChild]'},
    }

    def __init__(self, account_id=None, account_code=None, account_info=None, vendor=None, meters=None):
        super(DestinationAccountResponse, self).__init__()
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.vendor = vendor
        self.meters = meters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestSavingsMonthlyResponseResults(Model):
    """MeterDigestSavingsMonthlyResponseResults.

    :param calendar_period: Calendar Period
    :type calendar_period: int
    :param calendar_year: Calendar Year
    :type calendar_year: int
    :param fiscal_period: Fiscal Period
    :type fiscal_period: int
    :param fiscal_year: Fiscal Year
    :type fiscal_year: int
    :param period_name: Calendar Period Name
    :type period_name: str
    :param days: The number of days in the period
    :type days: int
    :param savings_total_cost: Total Cost
    :type savings_total_cost: float
    :param batcc_native_use: BATCC (Baseline Adjusted to Current Conditions)
     Native Use
    :type batcc_native_use: float
    :param native_use: Native Use
    :type native_use: float
    :param savings_native_use: Savings Native Use = BATCCNativeUse - NativeUse
    :type savings_native_use: float
    :param batcc_common_use: BATCC (Baseline Adjusted to Current Conditions)
     Common Use
    :type batcc_common_use: float
    :param common_use: Common Use
    :type common_use: float
    :param savings_common_use: Savings Common Use = BATCCCommonUse - CommonUse
    :type savings_common_use: float
    """

    _attribute_map = {
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'fiscal_period': {'key': 'fiscalPeriod', 'type': 'int'},
        'fiscal_year': {'key': 'fiscalYear', 'type': 'int'},
        'period_name': {'key': 'periodName', 'type': 'str'},
        'days': {'key': 'days', 'type': 'int'},
        'savings_total_cost': {'key': 'savingsTotalCost', 'type': 'float'},
        'batcc_native_use': {'key': 'batccNativeUse', 'type': 'float'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'savings_native_use': {'key': 'savingsNativeUse', 'type': 'float'},
        'batcc_common_use': {'key': 'batccCommonUse', 'type': 'float'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
        'savings_common_use': {'key': 'savingsCommonUse', 'type': 'float'},
    }

    def __init__(self, calendar_period=None, calendar_year=None, fiscal_period=None, fiscal_year=None, period_name=None, days=None, savings_total_cost=None, batcc_native_use=None, native_use=None, savings_native_use=None, batcc_common_use=None, common_use=None, savings_common_use=None):
        super(MeterDigestSavingsMonthlyResponseResults, self).__init__()
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.fiscal_period = fiscal_period
        self.fiscal_year = fiscal_year
        self.period_name = period_name
        self.days = days
        self.savings_total_cost = savings_total_cost
        self.batcc_native_use = batcc_native_use
        self.native_use = native_use
        self.savings_native_use = savings_native_use
        self.batcc_common_use = batcc_common_use
        self.common_use = common_use
        self.savings_common_use = savings_common_use



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountTemplateResponse(Model):
    """AccountTemplateResponse.

    :param form_template_id: The meter form template identifier
    :type form_template_id: int
    :param template_info: The template name
    :type template_info: str
    :param template_code: The template code
    :type template_code: str
    :param start_date: The start date for the form template on the account
     meter
    :type start_date: datetime
    :param end_date: The end date for the form template on the account meter
    :type end_date: datetime
    :param display_order: The form template's display order
    :type display_order: int
    :param meter: The meter the form template applies to
    :type meter: ~energycap.sdk.models.AccountMeterChild
    """

    _attribute_map = {
        'form_template_id': {'key': 'formTemplateId', 'type': 'int'},
        'template_info': {'key': 'templateInfo', 'type': 'str'},
        'template_code': {'key': 'templateCode', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'meter': {'key': 'meter', 'type': 'AccountMeterChild'},
    }

    def __init__(self, form_template_id=None, template_info=None, template_code=None, start_date=None, end_date=None, display_order=None, meter=None):
        super(AccountTemplateResponse, self).__init__()
        self.form_template_id = form_template_id
        self.template_info = template_info
        self.template_code = template_code
        self.start_date = start_date
        self.end_date = end_date
        self.display_order = display_order
        self.meter = meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Activity(Model):
    """Activity.

    :param id:
    :type id: int
    :param reason:
    :type reason: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'reason': {'key': 'reason', 'type': 'str'},
    }

    def __init__(self, id=None, reason=None):
        super(Activity, self).__init__()
        self.id = id
        self.reason = reason



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionCreate(Model):
    """RateVersionCreate.

    :param begin_date:  <span class='property-internal'>Required</span>
    :type begin_date: datetime
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type note: str
    :param bill_calculations:
    :type bill_calculations: list[~energycap.sdk.models.InputRequest]
    :param meter_details:
    :type meter_details: list[~energycap.sdk.models.InputRequest]
    :param rate_properties:
    :type rate_properties: list[~energycap.sdk.models.InputRequest]
    :param meter_properties:
    :type meter_properties: list[~energycap.sdk.models.InputRequest]
    :param account_properties:
    :type account_properties: list[~energycap.sdk.models.InputRequest]
    """

    _validation = {
        'begin_date': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'bill_calculations': {'key': 'billCalculations', 'type': '[InputRequest]'},
        'meter_details': {'key': 'meterDetails', 'type': '[InputRequest]'},
        'rate_properties': {'key': 'rateProperties', 'type': '[InputRequest]'},
        'meter_properties': {'key': 'meterProperties', 'type': '[InputRequest]'},
        'account_properties': {'key': 'accountProperties', 'type': '[InputRequest]'},
    }

    def __init__(self, begin_date, note=None, bill_calculations=None, meter_details=None, rate_properties=None, meter_properties=None, account_properties=None):
        super(RateVersionCreate, self).__init__()
        self.begin_date = begin_date
        self.note = note
        self.bill_calculations = bill_calculations
        self.meter_details = meter_details
        self.rate_properties = rate_properties
        self.meter_properties = meter_properties
        self.account_properties = account_properties



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingImportProfileResponse(Model):
    """ReadingImportProfileResponse.

    :param profile_id: The profile Indentifier
    :type profile_id: int
    :param profile_code: The profile code
    :type profile_code: str
    :param created_by: The user the profile was created by
    :type created_by: ~energycap.sdk.models.UserChild
    :param meter_import_id_column_number: The number of the column that holds
     the Meter import identifier
    :type meter_import_id_column_number: int
    :param channel_import_id_column_number: The number of the column that
     holds the Channel import identifier
    :type channel_import_id_column_number: int
    :param number_of_columns: The total number of columns in the import sheet
    :type number_of_columns: int
    :param channel_interval_in_seconds: The interval of the readings
    :type channel_interval_in_seconds: int
    :param delimiter: The string that represents how the file contents are
     delimeted.  Valid options are "\\t" for tab, " " for space and "," for
     comma.
    :type delimiter: str
    :param number_of_header_rows: Number of header rows before the data begins
    :type number_of_header_rows: int
    :param timestamp_column_number: The number of the column that holds the
     timestamp
    :type timestamp_column_number: int
    :param timestamp_format: The format for the timestamp of the readings. An
     example is MM/dd/yyyy mm:hh:ss:zzz
    :type timestamp_format: str
    :param date_column_number: The number of the column that holds the date
    :type date_column_number: int
    :param time_column_number: The number of the column that holds the time
    :type time_column_number: int
    :param date_format: The format for the date of the readings. An example is
     MM/dd/yyyy
    :type date_format: str
    :param time_format: The format for the time of the readings. An example is
     mm:hh:ss:zzz
    :type time_format: str
    :param time_zone: The time zone for the readings
    :type time_zone: ~energycap.sdk.models.TimeZoneChild
    :param data_mapping: A list of columns from the import sheet with their
     observation type and unit
    :type data_mapping: list[~energycap.sdk.models.ReadingImportProfileColumn]
    :param estimated: Column number and indicator to mark imported readings as
     estimated
    :type estimated: ~energycap.sdk.models.Estimated
    :param note_column_number: Column number that holds a note to be stored
     with the reading
    :type note_column_number: int
    """

    _attribute_map = {
        'profile_id': {'key': 'profileId', 'type': 'int'},
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'meter_import_id_column_number': {'key': 'meterImportIdColumnNumber', 'type': 'int'},
        'channel_import_id_column_number': {'key': 'channelImportIdColumnNumber', 'type': 'int'},
        'number_of_columns': {'key': 'numberOfColumns', 'type': 'int'},
        'channel_interval_in_seconds': {'key': 'channelIntervalInSeconds', 'type': 'int'},
        'delimiter': {'key': 'delimiter', 'type': 'str'},
        'number_of_header_rows': {'key': 'numberOfHeaderRows', 'type': 'int'},
        'timestamp_column_number': {'key': 'timestampColumnNumber', 'type': 'int'},
        'timestamp_format': {'key': 'timestampFormat', 'type': 'str'},
        'date_column_number': {'key': 'dateColumnNumber', 'type': 'int'},
        'time_column_number': {'key': 'timeColumnNumber', 'type': 'int'},
        'date_format': {'key': 'dateFormat', 'type': 'str'},
        'time_format': {'key': 'timeFormat', 'type': 'str'},
        'time_zone': {'key': 'timeZone', 'type': 'TimeZoneChild'},
        'data_mapping': {'key': 'dataMapping', 'type': '[ReadingImportProfileColumn]'},
        'estimated': {'key': 'estimated', 'type': 'Estimated'},
        'note_column_number': {'key': 'noteColumnNumber', 'type': 'int'},
    }

    def __init__(self, profile_id=None, profile_code=None, created_by=None, meter_import_id_column_number=None, channel_import_id_column_number=None, number_of_columns=None, channel_interval_in_seconds=None, delimiter=None, number_of_header_rows=None, timestamp_column_number=None, timestamp_format=None, date_column_number=None, time_column_number=None, date_format=None, time_format=None, time_zone=None, data_mapping=None, estimated=None, note_column_number=None):
        super(ReadingImportProfileResponse, self).__init__()
        self.profile_id = profile_id
        self.profile_code = profile_code
        self.created_by = created_by
        self.meter_import_id_column_number = meter_import_id_column_number
        self.channel_import_id_column_number = channel_import_id_column_number
        self.number_of_columns = number_of_columns
        self.channel_interval_in_seconds = channel_interval_in_seconds
        self.delimiter = delimiter
        self.number_of_header_rows = number_of_header_rows
        self.timestamp_column_number = timestamp_column_number
        self.timestamp_format = timestamp_format
        self.date_column_number = date_column_number
        self.time_column_number = time_column_number
        self.date_format = date_format
        self.time_format = time_format
        self.time_zone = time_zone
        self.data_mapping = data_mapping
        self.estimated = estimated
        self.note_column_number = note_column_number



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificAuditWithAuditGroup(Model):
    """SpecificAuditWithAuditGroup.

    :param audit_group:
    :type audit_group: ~energycap.sdk.models.BillAuditGroupChild
    :param specific_audit_id:
    :type specific_audit_id: int
    :param specific_audit_info:
    :type specific_audit_info: str
    :param auditor_id:
    :type auditor_id: int
    :param auditor_code:
    :type auditor_code: str
    :param description:
    :type description: str
    """

    _attribute_map = {
        'audit_group': {'key': 'auditGroup', 'type': 'BillAuditGroupChild'},
        'specific_audit_id': {'key': 'specificAuditId', 'type': 'int'},
        'specific_audit_info': {'key': 'specificAuditInfo', 'type': 'str'},
        'auditor_id': {'key': 'auditorId', 'type': 'int'},
        'auditor_code': {'key': 'auditorCode', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, audit_group=None, specific_audit_id=None, specific_audit_info=None, auditor_id=None, auditor_code=None, description=None):
        super(SpecificAuditWithAuditGroup, self).__init__()
        self.audit_group = audit_group
        self.specific_audit_id = specific_audit_id
        self.specific_audit_info = specific_audit_info
        self.auditor_id = auditor_id
        self.auditor_code = auditor_code
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAuditGroupCreate(Model):
    """BillAuditGroupCreate.

    :param audit_group_code: The bill audit group code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 16 characters</span>
    :type audit_group_code: str
    :param audit_group_info: The bill audit group name <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type audit_group_info: str
    :param description: The bill audit group description <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type description: str
    :param filters: List of filters to determine what bills to run this audit
     group on
    :type filters: list[~energycap.sdk.models.FilterEdit]
    :param specific_audits: List of bill audits to add to this group
    :type specific_audits: list[~energycap.sdk.models.SpecificAuditCreate]
    """

    _validation = {
        'audit_group_code': {'required': True, 'max_length': 16, 'min_length': 0},
        'audit_group_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'description': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'audit_group_code': {'key': 'auditGroupCode', 'type': 'str'},
        'audit_group_info': {'key': 'auditGroupInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'filters': {'key': 'filters', 'type': '[FilterEdit]'},
        'specific_audits': {'key': 'specificAudits', 'type': '[SpecificAuditCreate]'},
    }

    def __init__(self, audit_group_code, audit_group_info, description=None, filters=None, specific_audits=None):
        super(BillAuditGroupCreate, self).__init__()
        self.audit_group_code = audit_group_code
        self.audit_group_info = audit_group_info
        self.description = description
        self.filters = filters
        self.specific_audits = specific_audits



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerformanceComparisonDataResponse(Model):
    """PerformanceComparisonDataResponse.

    :param data_points:
    :type data_points:
     list[~energycap.sdk.models.PerformanceComparisonDataPoint]
    :param performance_comparisons:
    :type performance_comparisons:
     list[~energycap.sdk.models.PerformanceComparison]
    """

    _attribute_map = {
        'data_points': {'key': 'dataPoints', 'type': '[PerformanceComparisonDataPoint]'},
        'performance_comparisons': {'key': 'performanceComparisons', 'type': '[PerformanceComparison]'},
    }

    def __init__(self, data_points=None, performance_comparisons=None):
        super(PerformanceComparisonDataResponse, self).__init__()
        self.data_points = data_points
        self.performance_comparisons = performance_comparisons



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowStep(Model):
    """ChargebackWorkflowStep.

    :param chargeback_workflow_step_id: Identifier for the chargeback workflow
     step
    :type chargeback_workflow_step_id: int
    :param chargeback_workflow_step_info: Name given to the chargeback
     workflow step
    :type chargeback_workflow_step_info: str
    :param chargeback_workflow_step_description: Description for the
     chargeback workflow step
    :type chargeback_workflow_step_description: str
    :param chargeback_workflow_step_type: The chargeback type that can be
     assign to this chargeback workflow step.  Either "Split" or "Calculation"
    :type chargeback_workflow_step_type: str
    :param chargeback_workflow_step_order: The order for this step within the
     chargeback workflow
    :type chargeback_workflow_step_order: int
    """

    _attribute_map = {
        'chargeback_workflow_step_id': {'key': 'chargebackWorkflowStepId', 'type': 'int'},
        'chargeback_workflow_step_info': {'key': 'chargebackWorkflowStepInfo', 'type': 'str'},
        'chargeback_workflow_step_description': {'key': 'chargebackWorkflowStepDescription', 'type': 'str'},
        'chargeback_workflow_step_type': {'key': 'chargebackWorkflowStepType', 'type': 'str'},
        'chargeback_workflow_step_order': {'key': 'chargebackWorkflowStepOrder', 'type': 'int'},
    }

    def __init__(self, chargeback_workflow_step_id=None, chargeback_workflow_step_info=None, chargeback_workflow_step_description=None, chargeback_workflow_step_type=None, chargeback_workflow_step_order=None):
        super(ChargebackWorkflowStep, self).__init__()
        self.chargeback_workflow_step_id = chargeback_workflow_step_id
        self.chargeback_workflow_step_info = chargeback_workflow_step_info
        self.chargeback_workflow_step_description = chargeback_workflow_step_description
        self.chargeback_workflow_step_type = chargeback_workflow_step_type
        self.chargeback_workflow_step_order = chargeback_workflow_step_order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCreate(Model):
    """MeterCreate.

    :param meter_code: The meter code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type meter_code: str
    :param meter_info: The meter info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type meter_info: str
    :param commodity_id: The identifier for the meter's commodity <span
     class='property-internal'>Required</span>
    :type commodity_id: int
    :param place_id: The identifier for the place the meter is assigned to
     <span class='property-internal'>Topmost (Place)</span> <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param address: The address of the meter
    :type address: ~energycap.sdk.models.AddressChild
    :param bill_entry_note: The bill entry note <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type bill_entry_note: str
    :param include_in_energy_star: Indicates if the building is included in
     ENERGY STAR submissions
    :type include_in_energy_star: bool
    :param properties: An array of meter properties
    :type properties: dict[str, str]
    :param primary_use_id: The identifier for the meter's primary use
    :type primary_use_id: int
    :param meter_type_id: The identifier for the meter type. Allowed values
     include: 1 (standard meter) and 6 (chargeback meter) <span
     class='property-internal'>Required</span>
    :type meter_type_id: int
    :param meter_time_zone_id: The identifier for the meter's time zone. If
     one is not specified, the global default meter time zone will be used.
    :type meter_time_zone_id: int
    """

    _validation = {
        'meter_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'commodity_id': {'required': True},
        'place_id': {'required': True},
        'bill_entry_note': {'max_length': 64, 'min_length': 0},
        'meter_type_id': {'required': True},
    }

    _attribute_map = {
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'address': {'key': 'address', 'type': 'AddressChild'},
        'bill_entry_note': {'key': 'billEntryNote', 'type': 'str'},
        'include_in_energy_star': {'key': 'includeInEnergyStar', 'type': 'bool'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'primary_use_id': {'key': 'primaryUseId', 'type': 'int'},
        'meter_type_id': {'key': 'meterTypeId', 'type': 'int'},
        'meter_time_zone_id': {'key': 'meterTimeZoneId', 'type': 'int'},
    }

    def __init__(self, meter_code, meter_info, commodity_id, place_id, meter_type_id, address=None, bill_entry_note=None, include_in_energy_star=None, properties=None, primary_use_id=None, meter_time_zone_id=None):
        super(MeterCreate, self).__init__()
        self.meter_code = meter_code
        self.meter_info = meter_info
        self.commodity_id = commodity_id
        self.place_id = place_id
        self.address = address
        self.bill_entry_note = bill_entry_note
        self.include_in_energy_star = include_in_energy_star
        self.properties = properties
        self.primary_use_id = primary_use_id
        self.meter_type_id = meter_type_id
        self.meter_time_zone_id = meter_time_zone_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BatchCreate(Model):
    """BatchCreate.

    :param batch_code:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type batch_code: str
    :param close_existing_batch:
    :type close_existing_batch: bool
    :param statement_date:
    :type statement_date: datetime
    :param due_date:
    :type due_date: datetime
    :param next_reading:
    :type next_reading: datetime
    :param control_code:  <span class='property-internal'>Must be between 0
     and 255 characters</span>
    :type control_code: str
    :param invoice_number:  <span class='property-internal'>Must be between 0
     and 255 characters</span>
    :type invoice_number: str
    :param account_period_number:
    :type account_period_number: int
    :param account_period_year:  <span class='property-internal'>Must be
     between 1900 and 2099</span>
    :type account_period_year: int
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type note: str
    """

    _validation = {
        'batch_code': {'required': True, 'max_length': 255, 'min_length': 0},
        'control_code': {'max_length': 255, 'min_length': 0},
        'invoice_number': {'max_length': 255, 'min_length': 0},
        'account_period_year': {'maximum': 2099, 'minimum': 1900},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'batch_code': {'key': 'batchCode', 'type': 'str'},
        'close_existing_batch': {'key': 'closeExistingBatch', 'type': 'bool'},
        'statement_date': {'key': 'statementDate', 'type': 'iso-8601'},
        'due_date': {'key': 'dueDate', 'type': 'iso-8601'},
        'next_reading': {'key': 'nextReading', 'type': 'iso-8601'},
        'control_code': {'key': 'controlCode', 'type': 'str'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'str'},
        'account_period_number': {'key': 'accountPeriodNumber', 'type': 'int'},
        'account_period_year': {'key': 'accountPeriodYear', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, batch_code, close_existing_batch=None, statement_date=None, due_date=None, next_reading=None, control_code=None, invoice_number=None, account_period_number=None, account_period_year=None, note=None):
        super(BatchCreate, self).__init__()
        self.batch_code = batch_code
        self.close_existing_batch = close_existing_batch
        self.statement_date = statement_date
        self.due_date = due_date
        self.next_reading = next_reading
        self.control_code = control_code
        self.invoice_number = invoice_number
        self.account_period_number = account_period_number
        self.account_period_year = account_period_year
        self.note = note



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GuidResponse(Model):
    """GuidResponse.

    :param task_gu_id: A guid that identifies the current task
    :type task_gu_id: str
    """

    _attribute_map = {
        'task_gu_id': {'key': 'taskGUId', 'type': 'str'},
    }

    def __init__(self, task_gu_id=None):
        super(GuidResponse, self).__init__()
        self.task_gu_id = task_gu_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlertStatusResponse(Model):
    """AlertStatusResponse.

    :param alert_status_id:
    :type alert_status_id: int
    :param alert_status_info:
    :type alert_status_info: str
    """

    _attribute_map = {
        'alert_status_id': {'key': 'alertStatusId', 'type': 'int'},
        'alert_status_info': {'key': 'alertStatusInfo', 'type': 'str'},
    }

    def __init__(self, alert_status_id=None, alert_status_info=None):
        super(AlertStatusResponse, self).__init__()
        self.alert_status_id = alert_status_id
        self.alert_status_info = alert_status_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupDigestResponse(Model):
    """MeterGroupDigestResponse.

    :param meter_group_id:
    :type meter_group_id: int
    :param meter_group_code:
    :type meter_group_code: str
    :param meter_group_info:
    :type meter_group_info: str
    :param meter_group_display:
    :type meter_group_display: str
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param results:
    :type results: list[~energycap.sdk.models.MeterGroupDigestChild]
    """

    _attribute_map = {
        'meter_group_id': {'key': 'meterGroupId', 'type': 'int'},
        'meter_group_code': {'key': 'meterGroupCode', 'type': 'str'},
        'meter_group_info': {'key': 'meterGroupInfo', 'type': 'str'},
        'meter_group_display': {'key': 'meterGroupDisplay', 'type': 'str'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'results': {'key': 'results', 'type': '[MeterGroupDigestChild]'},
    }

    def __init__(self, meter_group_id=None, meter_group_code=None, meter_group_info=None, meter_group_display=None, updated=None, results=None):
        super(MeterGroupDigestResponse, self).__init__()
        self.meter_group_id = meter_group_id
        self.meter_group_code = meter_group_code
        self.meter_group_info = meter_group_info
        self.meter_group_display = meter_group_display
        self.updated = updated
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportProfileObservation(Model):
    """BillImportProfileObservation.

    :param column_index:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 1 and 2147483647</span>
    :type column_index: int
    :param observation_type_code:  <span
     class='property-internal'>Required</span>
    :type observation_type_code: str
    :param caption:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type caption: str
    :param unit_code:  <span class='property-internal'>Required</span>
    :type unit_code: str
    """

    _validation = {
        'column_index': {'required': True, 'maximum': 2147483647, 'minimum': 1},
        'observation_type_code': {'required': True},
        'caption': {'required': True, 'max_length': 32, 'min_length': 0},
        'unit_code': {'required': True},
    }

    _attribute_map = {
        'column_index': {'key': 'columnIndex', 'type': 'int'},
        'observation_type_code': {'key': 'observationTypeCode', 'type': 'str'},
        'caption': {'key': 'caption', 'type': 'str'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
    }

    def __init__(self, column_index, observation_type_code, caption, unit_code):
        super(BillImportProfileObservation, self).__init__()
        self.column_index = column_index
        self.observation_type_code = observation_type_code
        self.caption = caption
        self.unit_code = unit_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuditProperty(Model):
    """AuditProperty.

    :param property_id:
    :type property_id: int
    :param property_code:
    :type property_code: str
    :param description:
    :type description: str
    :param data_type:
    :type data_type: ~energycap.sdk.models.DataTypeResponse
    :param operator:
    :type operator: str
    :param value:
    :type value: str
    """

    _attribute_map = {
        'property_id': {'key': 'propertyId', 'type': 'int'},
        'property_code': {'key': 'propertyCode', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'data_type': {'key': 'dataType', 'type': 'DataTypeResponse'},
        'operator': {'key': 'operator', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, property_id=None, property_code=None, description=None, data_type=None, operator=None, value=None):
        super(AuditProperty, self).__init__()
        self.property_id = property_id
        self.property_code = property_code
        self.description = description
        self.data_type = data_type
        self.operator = operator
        self.value = value



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillImportProfileResponse(Model):
    """BillImportProfileResponse.

    :param profile_id:
    :type profile_id: int
    :param profile_code:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 64 characters</span>
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type profile_code: str
    :param column_mapping:
    :type column_mapping: ~energycap.sdk.models.BillImportProfileColumnMapping
    """

    _validation = {
        'profile_code': {'required': True, 'max_length': 64, 'min_length': 0},
    }

    _attribute_map = {
        'profile_id': {'key': 'profileId', 'type': 'int'},
        'profile_code': {'key': 'profileCode', 'type': 'str'},
        'column_mapping': {'key': 'columnMapping', 'type': 'BillImportProfileColumnMapping'},
    }

    def __init__(self, profile_code, profile_id=None, column_mapping=None):
        super(BillImportProfileResponse, self).__init__()
        self.profile_id = profile_id
        self.profile_code = profile_code
        self.column_mapping = column_mapping



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteMeter(Model):
    """RouteMeter.

    :param meter_id: The identifier for the meter <span
     class='property-internal'>Required</span>
    :type meter_id: int
    :param display_order: The display order for this route meter
    :type display_order: int
    """

    _validation = {
        'meter_id': {'required': True},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
    }

    def __init__(self, meter_id, display_order=None):
        super(RouteMeter, self).__init__()
        self.meter_id = meter_id
        self.display_order = display_order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ManualAdjustmentRequest(Model):
    """ManualAdjustmentRequest.

    :param batcc_native_use: The manually adjusted Baseline Adjusted to
     Current Conditions (BATCC) native use <span
     class='property-internal'>Required when locked is set to True</span>
    :type batcc_native_use: float
    :param batcc_cost: The manually adjusted Baseline Adjusted to Current
     Conditions (BATCC) cost <span class='property-internal'>Required when
     locked is set to True</span>
    :type batcc_cost: float
    :param bill_mtr_note: The manual adjustment note explaining the reason for
     the adjustment <span class='property-internal'>Required</span>
    :type bill_mtr_note: str
    :param locked: Indicates whether or not the values in a savings record are
     locked (this is not changed by future runs of the savings processor)
     Set to true when a manual adjustment is being created.
     Set to false when a manual adjustment is being removed.
     If locked is set to false, all other values are ignored and will be set by
     the savings processor. <span class='property-internal'>Required</span>
    :type locked: bool
    """

    _validation = {
        'bill_mtr_note': {'required': True},
        'locked': {'required': True},
    }

    _attribute_map = {
        'batcc_native_use': {'key': 'batccNativeUse', 'type': 'float'},
        'batcc_cost': {'key': 'batccCost', 'type': 'float'},
        'bill_mtr_note': {'key': 'billMtrNote', 'type': 'str'},
        'locked': {'key': 'locked', 'type': 'bool'},
    }

    def __init__(self, bill_mtr_note, locked, batcc_native_use=None, batcc_cost=None):
        super(ManualAdjustmentRequest, self).__init__()
        self.batcc_native_use = batcc_native_use
        self.batcc_cost = batcc_cost
        self.bill_mtr_note = bill_mtr_note
        self.locked = locked



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MonthlyCAPTrend(Model):
    """MonthlyCAPTrend.

    :param actual_cost:
    :type actual_cost: float
    :param cap_cost:
    :type cap_cost: float
    :param avoided_cost:
    :type avoided_cost: float
    :param percent_cost:
    :type percent_cost: float
    :param actual_use:
    :type actual_use: float
    :param cap_use:
    :type cap_use: float
    :param avoided_use:
    :type avoided_use: float
    :param percent_use:
    :type percent_use: float
    :param billing_period:
    :type billing_period: int
    """

    _attribute_map = {
        'actual_cost': {'key': 'actualCost', 'type': 'float'},
        'cap_cost': {'key': 'capCost', 'type': 'float'},
        'avoided_cost': {'key': 'avoidedCost', 'type': 'float'},
        'percent_cost': {'key': 'percentCost', 'type': 'float'},
        'actual_use': {'key': 'actualUse', 'type': 'float'},
        'cap_use': {'key': 'capUse', 'type': 'float'},
        'avoided_use': {'key': 'avoidedUse', 'type': 'float'},
        'percent_use': {'key': 'percentUse', 'type': 'float'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
    }

    def __init__(self, actual_cost=None, cap_cost=None, avoided_cost=None, percent_cost=None, actual_use=None, cap_use=None, avoided_use=None, percent_use=None, billing_period=None):
        super(MonthlyCAPTrend, self).__init__()
        self.actual_cost = actual_cost
        self.cap_cost = cap_cost
        self.avoided_cost = avoided_cost
        self.percent_cost = percent_cost
        self.actual_use = actual_use
        self.cap_use = cap_use
        self.avoided_use = avoided_use
        self.percent_use = percent_use
        self.billing_period = billing_period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAlertResponse(Model):
    """BillAlertResponse.

    :param bill_id:
    :type bill_id: int
    :param alert_id:
    :type alert_id: int
    :param message:
    :type message: str
    :param specific_audit:
    :type specific_audit: ~energycap.sdk.models.SpecificAuditWithAuditGroup
    :param alert_severity:
    :type alert_severity: ~energycap.sdk.models.AlertSeverityResponse
    :param message_type:
    :type message_type: str
    :param alert_status:
    :type alert_status: ~energycap.sdk.models.AlertStatusResponse
    :param comment:
    :type comment: str
    :param variance:
    :type variance: float
    :param created_date:
    :type created_date: datetime
    :param created_by:
    :type created_by: ~energycap.sdk.models.UserChild
    :param modified_date:
    :type modified_date: datetime
    :param modified_by:
    :type modified_by: ~energycap.sdk.models.UserChild
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'alert_id': {'key': 'alertId', 'type': 'int'},
        'message': {'key': 'message', 'type': 'str'},
        'specific_audit': {'key': 'specificAudit', 'type': 'SpecificAuditWithAuditGroup'},
        'alert_severity': {'key': 'alertSeverity', 'type': 'AlertSeverityResponse'},
        'message_type': {'key': 'messageType', 'type': 'str'},
        'alert_status': {'key': 'alertStatus', 'type': 'AlertStatusResponse'},
        'comment': {'key': 'comment', 'type': 'str'},
        'variance': {'key': 'variance', 'type': 'float'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'modified_by': {'key': 'modifiedBy', 'type': 'UserChild'},
    }

    def __init__(self, bill_id=None, alert_id=None, message=None, specific_audit=None, alert_severity=None, message_type=None, alert_status=None, comment=None, variance=None, created_date=None, created_by=None, modified_date=None, modified_by=None):
        super(BillAlertResponse, self).__init__()
        self.bill_id = bill_id
        self.alert_id = alert_id
        self.message = message
        self.specific_audit = specific_audit
        self.alert_severity = alert_severity
        self.message_type = message_type
        self.alert_status = alert_status
        self.comment = comment
        self.variance = variance
        self.created_date = created_date
        self.created_by = created_by
        self.modified_date = modified_date
        self.modified_by = modified_by



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListIds(Model):
    """ListIds.

    :param ids:
    :type ids: list[int]
    """

    _attribute_map = {
        'ids': {'key': 'ids', 'type': '[int]'},
    }

    def __init__(self, ids=None):
        super(ListIds, self).__init__()
        self.ids = ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserCreateRequest(Model):
    """UserCreateRequest.

    :param user_code:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type user_code: str
    :param full_name:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type full_name: str
    :param password:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type password: str
    :param email:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type email: str
    :param cost_center_id:  <span class='property-internal'>Required</span>
     <span class='property-internal'>Topmost (CostCenter)</span>
    :type cost_center_id: int
    :param place_id:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (Place)</span>
    :type place_id: int
    :param active_directory:
    :type active_directory: bool
    :param active:
    :type active: bool
    :param password_expiration_interval:  <span
     class='property-internal'>Required</span>
    :type password_expiration_interval: int
    :param strong_password:  <span class='property-internal'>Required</span>
    :type strong_password: bool
    :param force_password_change:  <span
     class='property-internal'>Required</span>
    :type force_password_change: bool
    :param user_role_id:  <span class='property-internal'>Required</span>
    :type user_role_id: int
    :param max_approval_amount:
    :type max_approval_amount: int
    :param report_group_id:
    :type report_group_id: int
    """

    _validation = {
        'user_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'full_name': {'required': True, 'max_length': 32, 'min_length': 0},
        'password': {'required': True, 'max_length': 128, 'min_length': 0},
        'email': {'required': True, 'max_length': 128, 'min_length': 0},
        'cost_center_id': {'required': True},
        'place_id': {'required': True},
        'password_expiration_interval': {'required': True},
        'strong_password': {'required': True},
        'force_password_change': {'required': True},
        'user_role_id': {'required': True},
    }

    _attribute_map = {
        'user_code': {'key': 'userCode', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'password': {'key': 'password', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'active_directory': {'key': 'activeDirectory', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'password_expiration_interval': {'key': 'passwordExpirationInterval', 'type': 'int'},
        'strong_password': {'key': 'strongPassword', 'type': 'bool'},
        'force_password_change': {'key': 'forcePasswordChange', 'type': 'bool'},
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
        'max_approval_amount': {'key': 'maxApprovalAmount', 'type': 'int'},
        'report_group_id': {'key': 'reportGroupId', 'type': 'int'},
    }

    def __init__(self, user_code, full_name, password, email, cost_center_id, place_id, password_expiration_interval, strong_password, force_password_change, user_role_id, active_directory=None, active=None, max_approval_amount=None, report_group_id=None):
        super(UserCreateRequest, self).__init__()
        self.user_code = user_code
        self.full_name = full_name
        self.password = password
        self.email = email
        self.cost_center_id = cost_center_id
        self.place_id = place_id
        self.active_directory = active_directory
        self.active = active
        self.password_expiration_interval = password_expiration_interval
        self.strong_password = strong_password
        self.force_password_change = force_password_change
        self.user_role_id = user_role_id
        self.max_approval_amount = max_approval_amount
        self.report_group_id = report_group_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PerformanceComparisonDataPoint(Model):
    """PerformanceComparisonDataPoint.

    :param period_number:
    :type period_number: int
    :param id:
    :type id: int
    :param cy_use:
    :type cy_use: float
    :param py_use:
    :type py_use: float
    :param cy_global_use:
    :type cy_global_use: float
    :param py_global_use:
    :type py_global_use: float
    """

    _attribute_map = {
        'period_number': {'key': 'periodNumber', 'type': 'int'},
        'id': {'key': 'id', 'type': 'int'},
        'cy_use': {'key': 'cyUse', 'type': 'float'},
        'py_use': {'key': 'pyUse', 'type': 'float'},
        'cy_global_use': {'key': 'cyGlobalUse', 'type': 'float'},
        'py_global_use': {'key': 'pyGlobalUse', 'type': 'float'},
    }

    def __init__(self, period_number=None, id=None, cy_use=None, py_use=None, cy_global_use=None, py_global_use=None):
        super(PerformanceComparisonDataPoint, self).__init__()
        self.period_number = period_number
        self.id = id
        self.cy_use = cy_use
        self.py_use = py_use
        self.cy_global_use = cy_global_use
        self.py_global_use = py_global_use



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListResponseListField(Model):
    """ListResponseListField.

    :param field_id: Column/Filter Identifier
    :type field_id: int
    :param width: Width of the column
    :type width: int
    :param display_order: Order of the column
    :type display_order: int
    :param sortable: Is the column sortable?
    :type sortable: bool
    :param caption: Caption for the column/filter
    :type caption: str
    :param sort_direction: Sort direction "asc" or "desc"
    :type sort_direction: str
    :param sort_order: Sort order for the column
    :type sort_order: int
    :param data_type_code: Type of Data in this column
    :type data_type_code: str
    :param required_output: Is this column a required column?
    :type required_output: bool
    :param visible: Is this column currently visible?
    :type visible: bool
    """

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'display_order': {'key': 'displayOrder', 'type': 'int'},
        'sortable': {'key': 'sortable', 'type': 'bool'},
        'caption': {'key': 'caption', 'type': 'str'},
        'sort_direction': {'key': 'sortDirection', 'type': 'str'},
        'sort_order': {'key': 'sortOrder', 'type': 'int'},
        'data_type_code': {'key': 'dataTypeCode', 'type': 'str'},
        'required_output': {'key': 'requiredOutput', 'type': 'bool'},
        'visible': {'key': 'visible', 'type': 'bool'},
    }

    def __init__(self, field_id=None, width=None, display_order=None, sortable=None, caption=None, sort_direction=None, sort_order=None, data_type_code=None, required_output=None, visible=None):
        super(ListResponseListField, self).__init__()
        self.field_id = field_id
        self.width = width
        self.display_order = display_order
        self.sortable = sortable
        self.caption = caption
        self.sort_direction = sort_direction
        self.sort_order = sort_order
        self.data_type_code = data_type_code
        self.required_output = required_output
        self.visible = visible



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillUnexportOptions(Model):
    """BillUnexportOptions.

    :param export_mode:  <span class='property-internal'>Required</span> <span
     class='property-internal'>One of ap, gl </span>
    :type export_mode: str
    """

    _validation = {
        'export_mode': {'required': True},
    }

    _attribute_map = {
        'export_mode': {'key': 'exportMode', 'type': 'str'},
    }

    def __init__(self, export_mode):
        super(BillUnexportOptions, self).__init__()
        self.export_mode = export_mode



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountCreate(Model):
    """AccountCreate.

    :param account_code: The account code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type account_code: str
    :param account_info: The account info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type account_info: str
    :param account_type_id: The identifier for the account type <span
     class='property-internal'>Required</span>
    :type account_type_id: int
    :param cost_center_id: The identifier for the cost center to which the
     account belongs <span class='property-internal'>Topmost
     (CostCenter)</span> <span class='property-internal'>Required</span>
    :type cost_center_id: int
    :param vendor_id: The identifier for the account's vendor <span
     class='property-internal'>Required</span>
    :type vendor_id: int
    :param customer_id: The identifier for the customer the account serves.
     This is normally only set for chargeback accounts
    :type customer_id: int
    :param contact_id: The identifier for the account's contact
    :type contact_id: int
    :param active: Indicates if the account is active or inactive
    :type active: bool
    :param accrual_enabled: Indicates if the account is used with accruals
    :type accrual_enabled: bool
    :param postal_code: The address postal code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 10 characters</span>
    :type postal_code: str
    :param city: The address city <span class='property-internal'>Must be
     between 0 and 32 characters</span>
    :type city: str
    :param state: The address state <span class='property-internal'>Must be
     between 0 and 3 characters</span>
    :type state: str
    :param country: The address country <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type country: str
    :param line1: The address first line <span class='property-internal'>Must
     be between 0 and 32 characters</span>
    :type line1: str
    :param line2: The address second line <span class='property-internal'>Must
     be between 0 and 32 characters</span>
    :type line2: str
    :param deposit_paid: The date and time the account deposit was paid
    :type deposit_paid: datetime
    :param deposit_return: The date and time the account deposit was returned
    :type deposit_return: datetime
    :param deposit_note: A note related to the account deposit
    :type deposit_note: str
    :param deposit_amount: The account deposit amount
    :type deposit_amount: float
    :param memo: The account memo
    :type memo: str
    :param service_start: The account's service begin date and time
    :type service_start: datetime
    :param service_end: The account's service end date and time
    :type service_end: datetime
    :param meters: An array of identifiers for meters attached to this account
    :type meters: list[int]
    :param general_ledger_id: The identifier for the account's generalLedgerId
    :type general_ledger_id: int
    """

    _validation = {
        'account_code': {'required': True, 'max_length': 50, 'min_length': 0},
        'account_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'account_type_id': {'required': True},
        'cost_center_id': {'required': True},
        'vendor_id': {'required': True},
        'postal_code': {'required': True, 'max_length': 10, 'min_length': 0},
        'city': {'max_length': 32, 'min_length': 0},
        'state': {'max_length': 3, 'min_length': 0},
        'country': {'required': True, 'max_length': 32, 'min_length': 0},
        'line1': {'max_length': 32, 'min_length': 0},
        'line2': {'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'account_type_id': {'key': 'accountTypeId', 'type': 'int'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'customer_id': {'key': 'customerId', 'type': 'int'},
        'contact_id': {'key': 'contactId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'accrual_enabled': {'key': 'accrualEnabled', 'type': 'bool'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'deposit_paid': {'key': 'depositPaid', 'type': 'iso-8601'},
        'deposit_return': {'key': 'depositReturn', 'type': 'iso-8601'},
        'deposit_note': {'key': 'depositNote', 'type': 'str'},
        'deposit_amount': {'key': 'depositAmount', 'type': 'float'},
        'memo': {'key': 'memo', 'type': 'str'},
        'service_start': {'key': 'serviceStart', 'type': 'iso-8601'},
        'service_end': {'key': 'serviceEnd', 'type': 'iso-8601'},
        'meters': {'key': 'meters', 'type': '[int]'},
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
    }

    def __init__(self, account_code, account_info, account_type_id, cost_center_id, vendor_id, postal_code, country, customer_id=None, contact_id=None, active=None, accrual_enabled=None, city=None, state=None, line1=None, line2=None, deposit_paid=None, deposit_return=None, deposit_note=None, deposit_amount=None, memo=None, service_start=None, service_end=None, meters=None, general_ledger_id=None):
        super(AccountCreate, self).__init__()
        self.account_code = account_code
        self.account_info = account_info
        self.account_type_id = account_type_id
        self.cost_center_id = cost_center_id
        self.vendor_id = vendor_id
        self.customer_id = customer_id
        self.contact_id = contact_id
        self.active = active
        self.accrual_enabled = accrual_enabled
        self.postal_code = postal_code
        self.city = city
        self.state = state
        self.country = country
        self.line1 = line1
        self.line2 = line2
        self.deposit_paid = deposit_paid
        self.deposit_return = deposit_return
        self.deposit_note = deposit_note
        self.deposit_amount = deposit_amount
        self.memo = memo
        self.service_start = service_start
        self.service_end = service_end
        self.meters = meters
        self.general_ledger_id = general_ledger_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedDemandRequest(Model):
    """FixedDemandRequest.

    :param fixed_demand_amount: Fixed demand amount <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     precision of 6</span>
    :type fixed_demand_amount: float
    :param unit_id: Unit to which demand is applied <span
     class='property-internal'>Required</span>
    :type unit_id: int
    """

    _validation = {
        'fixed_demand_amount': {'required': True},
        'unit_id': {'required': True},
    }

    _attribute_map = {
        'fixed_demand_amount': {'key': 'fixedDemandAmount', 'type': 'float'},
        'unit_id': {'key': 'unitId', 'type': 'int'},
    }

    def __init__(self, fixed_demand_amount, unit_id):
        super(FixedDemandRequest, self).__init__()
        self.fixed_demand_amount = fixed_demand_amount
        self.unit_id = unit_id
